/***************************************************************************************************/
/*script in Sql, generate by SdmCreateScript 2020(by Qihang Feng, QF255001@TERADATA.COM)     */
/*VERSION 01.10 revised on 2020-08-25                                                              */
/*Brilliance stems from wisdoms.                                                                   */
/*************Head Section**************************************************************************/
/*Script Use: Periodically load data to :cust_label_rela(客户标签关系表)             */
/*Create Date:2024-08-01 15:48:28                                                                  */
/*SDM Developed By: dev                                                                            */
/*SDM Developed Date: 2024-07-11                                                                   */
/*SDM Checked By: dev                                                                              */
/*SDM Checked Date: 2024-08-01                                                                     */
/*Script Developed By: dev                                                                         */
/*Script Checked By: dev                                                                           */
/*Source table 1: :PDMDB.t01_ccc_cust_info                                                         */
/*Source table 2: :PDMDB.t01_ccc_cust_label                                                        */
/*Job Type: Inbound transform (Tier 1 to Tier 2)                                                   */
/*Target Table:cust_label_rela                                                                     */
/*ETL Job Name:cust_label_rela                                                                     */
/*ETL Frequency:Daily                                                                              */
/*ETL Policy:F2                                                                                    */
/********************************************************************************************/
/*******Main Section**************************************************************************/
\set ON_ERROR_STOP on
\set AUTOCOMMIT on
\timing on



/*创建临时表加载当前数据                                                                           */
CREATE TEMPORARY TABLE cust_label_rela_agi_CUR_I 
 ( LIKE :COMMDB.cust_label_rela)
ON COMMIT PRESERVE ROWS;



/*创建临时表加载不同数据                                                                           */
CREATE TEMPORARY TABLE cust_label_rela_agi_INS 
( LIKE :COMMDB.cust_label_rela)
ON COMMIT PRESERVE ROWS;

            
/*****************************************************************************************************/
/* GROUP 1:Source Table:t01_ccc_cust_info*************************************************************/
/*****************************************************************************************************/

INSERT INTO cust_label_rela_agi_CUR_I (
            cust_id                                 /*客户编号*/
           ,cust_label_id                           /*客户标签编号*/
           ,cust_label_name                         /*客户标签名称*/
           ,cust_external_id                        /*客户外部企业ID*/
           ,Etl_Batch_No                            /*作业批次号*/
           ,Etl_First_Dt                            /*最初入库时间*/
           ,Etl_Job                                 /*作业名称*/
           ,Etl_Proc_Dt                             /*本次入库时间*/
           ,Etl_Tx_Dt                               /*作业运行时间*/
           ,Src_Sysname                             /*来源系统*/
           ,Src_Table                               /*来源表*/
        )
SELECT
         coalesce(p0.id,'')                                        /*cust_id*/
        ,coalesce(p0.label_id,'')                                  /*cust_label_id*/
        ,coalesce(p1.label_name,'')                                /*cust_label_name*/
        ,coalesce(p0.external_id,'')                               /*cust_external_id*/
        ,0                                                         /*Etl_Batch_No*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_First_Dt*/
        ,:ETLJOB                                                   /*Etl_Job*/
        ,current_timestamp(0)                                      /*Etl_Proc_Dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_Tx_Dt*/
        ,Substr('t01_ccc_cust_info',1,3)                           /*Src_Sysname*/
        ,'t01_ccc_cust_info'                                       /*Src_Table*/
        
FROM (select id,trim(unnest(string_to_array(replace(replace(label_ids,'[',''),']',''),','))) label_id,external_id  from p20_pdm.t01_ccc_cust_info tcci
where length(trim(external_id))>0) p0  
LEFT JOIN :PDMDB.t01_ccc_cust_label  p1
        ON p0.label_id=p1.label_id


;



/*将不同数据插入到临时表                                                                           */
;INSERT INTO cust_label_rela_agi_INS (
         cust_label_name                                           /*客户标签名称*/
        ,cust_external_id                                          /*客户外部企业ID*/
        ,cust_id                                                   /*客户编号*/
        ,cust_label_id                                             /*客户标签编号*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
    SELECT
         P1.cust_label_name                                           /*客户标签名称*/
        ,P1.cust_external_id                                          /*客户外部企业ID*/
        ,P1.cust_id                                                   /*客户编号*/
        ,P1.cust_label_id                                             /*客户标签编号*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM cust_label_rela_agi_CUR_I P1
LEFT JOIN :COMMDB.cust_label_rela P2
ON    P1.cust_label_name = P2.cust_label_name
    AND P1.cust_external_id = P2.cust_external_id
    AND P1.cust_id = P2.cust_id
    AND P1.cust_label_id = P2.cust_label_id
    
WHERE  P2.cust_label_name IS NULL
    OR P2.cust_external_id IS NULL
    OR P2.cust_id IS NULL
    OR P2.cust_label_id IS NULL
    
; 
/*将新增数据插入到目标表                                                                           */
;INSERT INTO :COMMDB.cust_label_rela (
         cust_label_name                                           /*客户标签名称*/
        ,cust_external_id                                          /*客户外部企业ID*/
        ,cust_id                                                   /*客户编号*/
        ,cust_label_id                                             /*客户标签编号*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
SELECT
         P1.cust_label_name                                           /*客户标签名称*/
        ,P1.cust_external_id                                          /*客户外部企业ID*/
        ,P1.cust_id                                                   /*客户编号*/
        ,P1.cust_label_id                                             /*客户标签编号*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM cust_label_rela_agi_INS P1
ON CONFLICT ( cust_id,cust_label_id)
DO UPDATE SET
     cust_id=excluded.cust_id
    ,cust_label_id=excluded.cust_label_id
    ,cust_label_name=excluded.cust_label_name
    ,cust_external_id=excluded.cust_external_id
    ,Etl_Batch_No=excluded.Etl_Batch_No
    ,Etl_First_Dt=excluded.Etl_First_Dt
    ,Etl_Job=excluded.Etl_Job
    ,Etl_Proc_Dt=excluded.Etl_Proc_Dt
    ,Etl_Tx_Dt=excluded.Etl_Tx_Dt
    ,Src_Sysname=excluded.Src_Sysname
    ,Src_Table=excluded.Src_Table
    

;
/*****程序结束退出                                               */
\q

